@@ -432,6 +432,25 @@ $.fn.fileuploadwidget = function(){
         });
 }
 
+function extract_select2_context(context, instance){
+    let data=instance.data();
+    let dropdownparent=data.dropdownparent;
+    let placeholder=data.placeholder;
+    let theme = data.theme;
+    if( dropdownparent != undefined){
+        context.dropdownParent = $(dropdownparent);
+    }
+    if( placeholder != undefined){
+        context.placeholder=placeholder;
+    }
+    if(theme != undefined){
+        context.theme=theme;
+    }else{
+        context.theme='bootstrap-5'
+    }
+}
+
+window.extract_select2_context=extract_select2_context;
 $.fn.select2related = function(action, relatedobjs=[]) {
     /**
         [{ 'id': '#myfield',
@@ -451,13 +470,15 @@ $.fn.select2related = function(action, relatedobjs=[]) {
 
         if(action === "simple"){
             for(let x=0; x<this.relatedobjs.length; x++){
-                $(this.relatedobjs[x]['id']).select2();
+                let contexts2={};
+                extract_select2_context(contexts2, $(this.relatedobjs[x]['id']));
+                $(this.relatedobjs[x]['id']).select2(contexts2);
             }
         }
 
         if(action === 'remote'){
             for(let x=0; x<this.relatedobjs.length; x++){
-                $(this.relatedobjs[x]['id']).select2({
+                let contexts2={
                       placeholder: 'Select an element',
                       ajax: {
                         url: this.relatedobjs[x]['url'],
@@ -473,12 +494,14 @@ $.fn.select2related = function(action, relatedobjs=[]) {
                               return dev;
                         },
                       }
-                });
+                };
+                extract_select2_context(contexts2, $(this.relatedobjs[x]['id']));
+                $(this.relatedobjs[x]['id']).select2(contexts2);
             }
         }
         if(action === "related"){
             for(let x=1; x<this.relatedobjs.length; x++){
-                let newselect = $(this.relatedobjs[x]['id']).select2({
+                let contexts2={
                   placeholder: 'Select an element',
                   ajax: {
                     url: this.relatedobjs[x]['url'],
@@ -495,13 +518,14 @@ $.fn.select2related = function(action, relatedobjs=[]) {
                       return dev;
                     },
                   }
-                });
+                };
+                extract_select2_context(contexts2, $(this.relatedobjs[x]['id']));
+                let newselect = $(this.relatedobjs[x]['id']).select2(contexts2);
                 if(parent.relatedobjs[x]['start_empty']){
                     newselect.val(null).trigger('change');
                 }
             }
-
-            let newselect = $(this.relatedobjs[0]['id']).select2({
+            let contexts2empty = {
               placeholder: 'Select an element',
               ajax: {
                 url: parent.relatedobjs[0]['url'],
@@ -515,7 +539,9 @@ $.fn.select2related = function(action, relatedobjs=[]) {
                       }
                     },
               }
-            });
+            };
+            extract_select2_context(contexts2empty, $(this.relatedobjs[0]['id']));
+            let newselect = $(this.relatedobjs[0]['id']).select2(contexts2empty);
             if(this.relatedobjs[0]['start_empty']){
                 newselect.val(null).trigger('change');
             }
